/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995-2003 Peter Mattis and Spencer Kimball
 *
 * gimpgimprc_pdb.h
 *
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <https://www.gnu.org/licenses/>.
 */

/* NOTE: This file is auto-generated by pdbgen.pl */

#if !defined (__GIMP_H_INSIDE__) && !defined (GIMP_COMPILATION)
#error "Only <libgimp/gimp.h> can be included directly."
#endif

#ifndef __GIMP_GIMPRC_PDB_H__
#define __GIMP_GIMPRC_PDB_H__

G_BEGIN_DECLS

/* For information look into the C source or the html documentation */


gchar*                 gimp_gimprc_query             (const gchar *token);
gboolean               gimp_gimprc_set               (const gchar *token,
                                                      const gchar *value);
gchar*                 gimp_get_default_comment      (void);
GimpUnit               gimp_get_default_unit         (void);
gboolean               gimp_get_monitor_resolution   (gdouble     *xres,
                                                      gdouble     *yres);
GIMP_DEPRECATED
gchar*                 gimp_get_theme_dir            (void);
GIMP_DEPRECATED
gchar*                 gimp_get_icon_theme_dir       (void);
G_GNUC_INTERNAL gchar* _gimp_get_color_configuration (void);
gchar*                 gimp_get_module_load_inhibit  (void);


G_END_DECLS

#endif /* __GIMP_GIMPRC_PDB_H__ */
